   ID   PROVIDER            MODULE                          FUNCTION NAME
   ID   PROVIDER            MODULE                          FUNCTION NAME
   ID   PROVIDER            MODULE                          FUNCTION NAME
   ID   PROVIDER            MODULE                          FUNCTION NAME
   ID   PROVIDER            MODULE                          FUNCTION NAME
-- @@stderr --
dtrace: failed to match ::profile:: No probe matches description
dtrace: failed to match ::vmlinux:: No probe matches description
dtrace: failed to match vmlinux:::: No probe matches description
dtrace: failed to match :read::: No probe matches description
dtrace: failed to match :readfoo*::: No probe matches description
dtrace: invalid probe specifier profile:::tick-1000: invalid probe description "profile:::tick-1000": Overspecified probe description
dtrace: invalid probe specifier fbt:des:des3_crunch_block:return: invalid probe description "fbt:des:des3_crunch_block:return": Overspecified probe description
dtrace: invalid probe specifier read: extraneous argument '{printf("FOUND");}' ($1 is not referenced)
